==> v8.3.zip: ru_twords_ru_tw/bible/other/tax.md <==
# налог (устар. подать), пошлина, налогообложение, налогоплательщик, сборщик налогов, мытарь

## Определение:

Налогом или налогами называются деньги или товары, которые люди отдают в уплату правительству или стоящей над ними власти. Сборщик налогов (устар. — мытарь) был государственным работником, чьей обязанностью был сбор денег, которые люди должны были платить правительству в виде налогов.

* Размер налога обычно определялся ценностью производимого товара или величиной личного имущества человека.
* Во времена Иисуса Христа и апостолов римское правительство облагало налогами всех, кто жил в Римской империи, включая евреев.
* Если человек не платил налоги, римские власти могли принять карательные меры в отношении этого человека или его ремесла, чтобы получить налог.
* Иосиф и Мария отправились в Вифлеем на перепись населения, предназначенную для подсчёта налога со всех жителей Римской империи.
* Слово “налог” может быть переведено как “требуемый платёж”, “правительственные деньги” или “храмовые деньги” в зависимости от контекста.
* Словосочетание “платить налоги” можно перевести как “заплатить деньги правительству” или “внести требуемый платёж”. Словосочетание “собирать налоги” можно перевести как “получать деньги для правительства”.
* Сборщиком налогов (устар. — мытарем) называли человека, работающего на правительство, чья функция состояла в получении денег с людей, обязанных платить налоги.
* Сборщики налогов (устар. — мытари), собиравшие деньги для римского правительства, часто требовали больше, чем был обязан платить человек. Сборщики налогов присваивали себе эту дополнительную сумму.
* Из-за того, что сборщики налогов таким образом обманывали людей, евреи считали их наихудшими грешниками.
* Евреи также считали сборщиков налогов из своего народа предателями, потому что они работали на римское правительство, которое угнетало еврейский народ.
* Фраза “мытари и грешники” была весьма распространённым выражением в Новом Завете. В ней отражалось всё презрение, которое испытывали евреи к сборщикам налогов.

(См. также: [Вифлеем](../names/bethlehem.md), перепись, гражданин, иудей, [Рим](../names/rome.md), [грех](../kt/sin.md))

## Ссылки на библейский текст:

* [Лк. 20:21-22](rc://*/tn/help/luk/20/21)
* [Мк. 2:13-14](rc://*/tn/help/mrk/02/13)
* [Мф. 9:7-9](rc://*/tn/help/mat/09/07)
* [Чис. 31:28-29](rc://*/tn/help/num/31/28)
* [Рим. 13:6-7](rc://*/tn/help/rom/13/06)
* [Лк. 3:12-13](rc://*/tn/help/luk/03/12)
* [Лк. 5:27-28](rc://*/tn/help/luk/05/27)
* [Мф. 5:46-48](rc://*/tn/help/mat/05/46)
* [Мф. 9:10-11](rc://*/tn/help/mat/09/10)
* [Мф. 11:18-19](rc://*/tn/help/mat/11/18)
* [Мф. 17:26-27](rc://*/tn/help/mat/17/26)
* [Мф. 18:17](rc://*/tn/help/mat/18/17)

## Примеры из Библейских историй:

* 34:6 He said, "Two men went to the Temple to pray. One of them was a tax collector, and the other was a religious leader."
* 34:7 "The religious leader prayed like this, 'Thank you, God, that I am not a sinner like other men—such as robbers, unjust men, adulterers, or even like that tax collector.'"
* 34:9 "But the tax collector stood far away from the religious ruler, did not even look up to heaven. Instead, he pounded on his chest and prayed, 'God, please be merciful to me because I am a sinner.'"
* 34:10 Then Jesus said, "I tell you the truth, God heard the tax collector's prayer and declared him to be righteous."
* 35:1 One day, Jesus was teaching many tax collectors and other sinners who had gathered to hear him.

## Данные о слове:

* Налог: Номера Стронга: H2670, H4060, H4371, H4522, H4864, H6186, G583, G5411
* Сборщик налогов: Номера Стронга: H5065, H5674, G5057, G5058

==> v9.2.zip: ru_twords_ru_tw/bible/other/tax.md <==
# налог (устар. подать), пошлина, налогообложение, налогоплательщик, сборщик налогов, мытарь

## Определение:

Налогом или налогами называются деньги или товары, которые люди отдают в уплату правительству или стоящей над ними власти. Сборщик налогов (устар. — мытарь) был государственным работником, чьей обязанностью был сбор денег, которые люди должны были платить правительству в виде налогов.
* Размер налога обычно определялся ценностью производимого товара или величиной личного имущества человека.
* Во времена Иисуса Христа и апостолов римское правительство облагало налогами всех, кто жил в Римской империи, включая евреев.
* Если человек не платил налоги, римские власти могли принять карательные меры в отношении этого человека или его ремесла, чтобы получить налог.
* Иосиф и Мария отправились в Вифлеем на перепись населения, предназначенную для подсчёта налога со всех жителей Римской империи.
* Слово “налог” может быть переведено как “требуемый платёж”, “правительственные деньги” или “храмовые деньги” в зависимости от контекста.
* Словосочетание “платить налоги” можно перевести как “заплатить деньги правительству” или “внести требуемый платёж”. Словосочетание “собирать налоги” можно перевести как “получать деньги для правительства”.
* Сборщиком налогов (устар. — мытарем) называли человека, работающего на правительство, чья функция состояла в получении денег с людей, обязанных платить налоги.
* Сборщики налогов (устар. — мытари), собиравшие деньги для римского правительства, часто требовали больше, чем был обязан платить человек. Сборщики налогов присваивали себе эту дополнительную сумму.
* Из-за того, что сборщики налогов таким образом обманывали людей, евреи считали их наихудшими грешниками.
* Евреи также считали сборщиков налогов из своего народа предателями, потому что они работали на римское правительство, которое угнетало еврейский народ.
* Фраза “мытари и грешники” была весьма распространённым выражением в Новом Завете. В ней отражалось всё презрение, которое испытывали евреи к сборщикам налогов.

(См. также: [Вифлеем](../names/Bethlehem.md), перепись, гражданин, иудей, [Рим](../names/rome.md), [грех](../names/sin.md))


## Ссылки на библейский текст:

* [Лк. 20:21-22](rc://ru/tn/help/luk/20/21)
* [Мк. 2:13-14](rc://ru/tn/help/mrk/02/13)
* [Мф. 9:7-9](rc://ru/tn/help/mat/09/07)
* [Чис. 31:28-29](rc://ru/tn/help/num/31/28)
* [Рим. 13:6-7](rc://ru/tn/help/rom/13/06)
* [Лк. 3:12-13](rc://ru/tn/help/luk/03/12)
* [Лк. 5:27-28](rc://ru/tn/help/luk/05/27)
* [Мф. 5:46-48](rc://ru/tn/help/mat/05/46)
* [Мф. 9:10-11](rc://ru/tn/help/mat/09/10)
* [Мф. 11:18-19](rc://ru/tn/help/mat/11/18)
* [Мф. 17:26-27](rc://ru/tn/help/mat/17/26)
* [Мф. 18:17](rc://ru/tn/help/mat/18/17)

## Примеры из Библейских историй:

* 34:6 He said, "Two men went to the Temple to pray. One of them was a tax collector, and the other was a religious leader."
* 34:7 "The religious leader prayed like this, 'Thank you, God, that I am not a sinner like other men—such as robbers, unjust men, adulterers, or even like that tax collector.'"
* 34:9 "But the tax collector stood far away from the religious ruler, did not even look up to heaven. Instead, he pounded on his chest and prayed, 'God, please be merciful to me because I am a sinner.'"
* 34:10 Then Jesus said, "I tell you the truth, God heard the tax collector's prayer and declared him to be righteous."
* 35:1 One day, Jesus was teaching many tax collectors and other sinners who had gathered to hear him.

## Данные о слове:

* Налог: Номера Стронга: H2670, H4060, H4371, H4522, H4864, H6186, G583, G5411
* Сборщик налогов: Номера Стронга: H5065, H5674, G5057, G5058
